### Notes

The “Notes” tab in Font View stores a text note.
It is not exported and is used only for working in Glyphs.
The font note corresponds to the note custom parameter of the font.

The text field uses syntax highlighting for Markdown.
Italic (*italic*, _italic_), bold (**bold**, __bold__), hyperlinks ([Link Text](https://example.org) & <https://example.org>), and heading (#, ##, ###, ####, #####, ######) formatting are supported.